summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/gwcontact.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/groupwise/gwcontact.h')
-rw-r--r--kopete/protocols/groupwise/gwcontact.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/kopete/protocols/groupwise/gwcontact.h b/kopete/protocols/groupwise/gwcontact.h
index 64486e75..183df1a4 100644
--- a/kopete/protocols/groupwise/gwcontact.h
+++ b/kopete/protocols/groupwise/gwcontact.h
@@ -53,19 +53,20 @@ using namespace GroupWise;
class GroupWiseContact : public Kopete::Contact
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor
* @param account The GroupWiseAccount this belongs to.
* @param uniqueName The userId for this contact. May be a DN, in which case it will be converted to dotted format for the contactId and stored.
* @param parent The Kopete::MetaContact this contact is part of.
* @param objectId The contact's numeric object ID.
* @param parentId The ID of this contact's parent (folder).
* @param sequence This contact's sequence number (The position it appears in within its parent).
*/
GroupWiseContact( Kopete::Account* account, const TQString &uniqueName,
- Kopete::MetaContact *parent,
- const int objectId, const int parentId, const int sequence );
+ Kopete::MetaContact *tqparent,
+ const int objectId, const int tqparentId, const int sequence );
~GroupWiseContact();
@@ -131,11 +132,11 @@ public:
*/
void setDeleting( bool deleting );
/**
- * Marks this contact as having sent a message whilst apparently offline
+ * Marks this contact as having sent a message whilst aptqparently offline
*/
void setMessageReceivedOffline( bool on );
/**
- * Has this contact sent a message whilst apparently offline?
+ * Has this contact sent a message whilst aptqparently offline?
*/
bool messageReceivedOffline() const;
@@ -53,19 +53,20 @@ using namespace GroupWise;
* @param account The GroupWiseAccount this belongs to.
* @param uniqueName The userId for this contact. May be a DN, in which case it will be converted to dotted format for the contactId and stored.
- * @param parent The Kopete::MetaContact this contact is part of.
+ * @param tqparent The Kopete::MetaContact this contact is part of.
* @param objectId The contact's numeric object ID.
@@ -53,19 +53,20 @@ using namespace GroupWise;
* @param objectId The contact's numeric object ID.
- * @param parentId The ID of this contact's parent (folder).
- * @param sequence This contact's sequence number (The position it appears in within its parent).
+ * @param tqparentId The ID of this contact's tqparent (folder).
+ * @param sequence This contact's sequence number (The position it appears in within its tqparent).
*/
GroupWiseContact( Kopete::Account* account, const TQString &uniqueName,